==> aliyun-python-sdk-emr-3.3.0.tar.gz: aliyun-python-sdk-emr-3.3.0/aliyunsdkemr/request/v20160408/DumpMetaDataSourceForOuterRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkemr.endpoint import endpoint_data

class DumpMetaDataSourceForOuterRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Emr', '2016-04-08', 'DumpMetaDataSourceForOuter','emr')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_DumpAllDatabase(self):
		return self.get_query_params().get('DumpAllDatabase')

	def set_DumpAllDatabase(self,DumpAllDatabase):
		self.add_query_param('DumpAllDatabase',DumpAllDatabase)

	def get_DumpLimit(self):
		return self.get_query_params().get('DumpLimit')

	def set_DumpLimit(self,DumpLimit):
		self.add_query_param('DumpLimit',DumpLimit)

	def get_ClusterId(self):
		return self.get_query_params().get('ClusterId')

	def set_ClusterId(self,ClusterId):
		self.add_query_param('ClusterId',ClusterId)

	def get_DumpAllTable(self):
		return self.get_query_params().get('DumpAllTable')

	def set_DumpAllTable(self,DumpAllTable):
		self.add_query_param('DumpAllTable',DumpAllTable)

	def get_PartitionValuess(self):
		return self.get_query_params().get('PartitionValuess')

	def set_PartitionValuess(self, PartitionValuess):
		for depth1 in range(len(PartitionValuess)):
			if PartitionValuess[depth1] is not None:
				self.add_query_param('PartitionValues.' + str(depth1 + 1) , PartitionValuess[depth1])

	def get_TableId(self):
		return self.get_query_params().get('TableId')

	def set_TableId(self,TableId):
		self.add_query_param('TableId',TableId)

	def get_DatabaseId(self):
		return self.get_query_params().get('DatabaseId')

	def set_DatabaseId(self,DatabaseId):
		self.add_query_param('DatabaseId',DatabaseId)

	def get_DumpAllPartition(self):
		return self.get_query_params().get('DumpAllPartition')

	def set_DumpAllPartition(self,DumpAllPartition):
		self.add_query_param('DumpAllPartition',DumpAllPartition)

==> aliyun-python-sdk-emr-3.3.2.tar.gz: aliyun-python-sdk-emr-3.3.2/aliyunsdkemr/request/v20160408/DumpMetaDataSourceForOuterRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkemr.endpoint import endpoint_data

class DumpMetaDataSourceForOuterRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Emr', '2016-04-08', 'DumpMetaDataSourceForOuter')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_DumpAllDatabase(self):
		return self.get_query_params().get('DumpAllDatabase')

	def set_DumpAllDatabase(self,DumpAllDatabase):
		self.add_query_param('DumpAllDatabase',DumpAllDatabase)

	def get_DumpLimit(self):
		return self.get_query_params().get('DumpLimit')

	def set_DumpLimit(self,DumpLimit):
		self.add_query_param('DumpLimit',DumpLimit)

	def get_ClusterId(self):
		return self.get_query_params().get('ClusterId')

	def set_ClusterId(self,ClusterId):
		self.add_query_param('ClusterId',ClusterId)

	def get_DumpAllTable(self):
		return self.get_query_params().get('DumpAllTable')

	def set_DumpAllTable(self,DumpAllTable):
		self.add_query_param('DumpAllTable',DumpAllTable)

	def get_PartitionValuess(self):
		return self.get_query_params().get('PartitionValues')

	def set_PartitionValuess(self, PartitionValuess):
		for depth1 in range(len(PartitionValuess)):
			if PartitionValuess[depth1] is not None:
				self.add_query_param('PartitionValues.' + str(depth1 + 1) , PartitionValuess[depth1])

	def get_TableId(self):
		return self.get_query_params().get('TableId')

	def set_TableId(self,TableId):
		self.add_query_param('TableId',TableId)

	def get_DatabaseId(self):
		return self.get_query_params().get('DatabaseId')

	def set_DatabaseId(self,DatabaseId):
		self.add_query_param('DatabaseId',DatabaseId)

	def get_DumpAllPartition(self):
		return self.get_query_params().get('DumpAllPartition')

	def set_DumpAllPartition(self,DumpAllPartition):
		self.add_query_param('DumpAllPartition',DumpAllPartition)
